LineStep

Struct LineStep 

pub struct LineStep { /* private fields */ }
An explicit iterator over lines in a particular slice of bytes.

This iterator avoids borrowing the bytes themselves, and instead requires callers to explicitly provide the bytes when moving through the iterator.

Line terminators are considered part of the line they terminate. All lines yielded by the iterator are guaranteed to be non-empty.

Implementations

Source

impl LineStep

pub fn new(line_term: u8, start: usize, end: usize) -> LineStep

Create a new line iterator over the given range of bytes using the given line terminator.

pub fn next_match(&mut self, bytes: &[u8]) -> Option<Match>

Like next, but returns a Match instead of a tuple.