Searcher

Struct Searcher 

pub struct Searcher { /* private fields */ }
A searcher executes searches over a haystack and writes results to a caller provided sink.

Implementations

Source

impl Searcher

pub fn new() -> Searcher

Create a new searcher with a default configuration.

pub fn search_slice<M, S>( &self, matcher: M, slice: &[u8], write_to: S, ) -> Result<(), S::Error>
where M: Matcher, S: Sink,

Execute a search over the given slice and write the results to the given sink.

Source

impl Searcher

Configuration query methods used by the sink and internal search core.

pub fn line_terminator(&self) -> LineTerminator

Returns the line terminator used by this searcher.

pub fn line_number(&self) -> bool

Returns true if and only if this searcher is configured to count line numbers.

pub fn multi_line(&self) -> bool

Returns true if and only if this searcher is configured to perform multi line search.

pub fn multi_line_with_matcher<M: Matcher>(&self, matcher: M) -> bool

Returns true if and only if this searcher will choose a multi-line strategy given the provided matcher.