pub struct LineStep { /* private fields */ }Expand description
An explicit iterator over lines in a particular slice of bytes.
This iterator avoids borrowing the bytes themselves, and instead requires callers to explicitly provide the bytes when moving through the iterator.
Line terminators are considered part of the line they terminate. All lines yielded by the iterator are guaranteed to be non-empty.
Implementations