pub struct Searcher { /* private fields */ }Expand description
A searcher executes searches over a haystack and writes results to a caller provided sink.
Implementations
Sourceimpl Searcher
Configuration query methods used by the sink and internal search core.
impl Searcher
Configuration query methods used by the sink and internal search core.
Sourcepub fn line_terminator(&self) -> LineTerminator
pub fn line_terminator(&self) -> LineTerminator
Returns the line terminator used by this searcher.
Sourcepub fn line_number(&self) -> bool
pub fn line_number(&self) -> bool
Returns true if and only if this searcher is configured to count line numbers.
Sourcepub fn multi_line(&self) -> bool
pub fn multi_line(&self) -> bool
Returns true if and only if this searcher is configured to perform multi line search.
Sourcepub fn multi_line_with_matcher<M: Matcher>(&self, matcher: M) -> bool
pub fn multi_line_with_matcher<M: Matcher>(&self, matcher: M) -> bool
Returns true if and only if this searcher will choose a multi-line strategy given the provided matcher.